@@ -8,7 +8,6 @@ require 'raven/error'
 require 'raven/linecache'
 
 module Raven
-
   class Event
     LOG_LEVELS = {
       "debug" => 10,
@@ -16,25 +15,25 @@ module Raven
       "warn" => 30,
       "warning" => 30,
       "error" => 40,
-      "fatal" => 50,
+      "fatal" => 50
     }.freeze
 
     BACKTRACE_RE = /^(.+?):(\d+)(?::in `(.+?)')?$/
 
     PLATFORM = "ruby".freeze
+    SDK = { "name" => "sentry-raven", "version" => Raven::VERSION }.freeze
 
-    attr_reader :id
-    attr_accessor :project, :message, :timestamp, :time_spent, :level, :logger,
-      :culprit, :server_name, :release, :modules, :extra, :tags, :context, :configuration,
-      :checksum, :fingerprint
+    attr_accessor :id, :timestamp, :time_spent, :level, :logger,
+                  :culprit, :server_name, :release, :modules, :extra, :tags,
+                  :context, :configuration, :checksum, :fingerprint, :environment,
+                  :os, :runtime, :breadcrumbs, :user, :backtrace
 
     def initialize(init = {})
       @configuration = Raven.configuration
       @interfaces    = {}
+      @breadcrumbs   = Raven.breadcrumbs
       @context       = Raven.context
-      @id            = generate_event_id
-      @project       = nil
-      @message       = nil
+      @id            = SecureRandom.uuid.delete("-")
       @timestamp     = Time.now.utc
       @time_spent    = nil
       @level         = :error
@@ -43,11 +42,14 @@ module Raven
       @server_name   = @configuration.server_name
       @release       = @configuration.release
       @modules       = list_gem_specs if @configuration.send_modules
-      @user          = {}
-      @extra         = {}
-      @tags          = {}
+      @user          = {} # TODO: contexts
+      @extra         = {} # TODO: contexts
+      @os            = {} # TODO: contexts
+      @runtime       = {} # TODO: contexts
+      @tags          = {} # TODO: contexts
       @checksum      = nil
       @fingerprint   = nil
+      @environment   = @configuration.current_environment
 
       yield self if block_given?
 
@@ -57,18 +59,36 @@ module Raven
         end
       end
 
-      init.each_pair { |key, val| instance_variable_set('@' + key.to_s, val) }
+      if @context.rack_env # TODO: contexts
+        @context.user[:ip_address] = calculate_real_ip_from_rack
+      end
 
-      @user = @context.user.merge(@user)
-      @extra = @context.extra.merge(@extra)
-      @tags = @configuration.tags.merge(@context.tags).merge(@tags)
+      init.each_pair { |key, val| public_send(key.to_s + "=", val) }
+
+      @user = @context.user.merge(@user) # TODO: contexts
+      @extra = @context.extra.merge(@extra) # TODO: contexts
+      @tags = @configuration.tags.merge(@context.tags).merge(@tags) # TODO: contexts
+      @os = @context.os # TODO: contexts
+      @runtime = @context.runtime # TODO: contexts
 
       # Some type coercion
       @timestamp  = @timestamp.strftime('%Y-%m-%dT%H:%M:%S') if @timestamp.is_a?(Time)
-      @time_spent = (@time_spent*1000).to_i if @time_spent.is_a?(Float)
+      @time_spent = (@time_spent * 1000).to_i if @time_spent.is_a?(Float)
       @level      = LOG_LEVELS[@level.to_s.downcase] if @level.is_a?(String) || @level.is_a?(Symbol)
     end
 
+    def message
+      @interfaces[:logentry] && @interfaces[:logentry].unformatted_message
+    end
+
+    def message=(args)
+      message, params = *args
+      interface(:message) do |int|
+        int.message = message
+        int.params = params
+      end
+    end
+
     class << self
       def from_exception(exc, options = {}, &block)
         exception_context = get_exception_context(exc) || {}
@@ -97,14 +117,13 @@ module Raven
       end
 
       def from_message(message, options = {})
+        message = message.byteslice(0...10_000) # Messages limited to 10kb
         configuration = options[:configuration] || Raven.configuration
+
         new(options) do |evt|
           evt.configuration = configuration
-          evt.message = message
           evt.level = options[:level] || :error
-          evt.interface :message do |int|
-            int.message = message
-          end
+          evt.message = message, options[:message_params] || []
           if options[:backtrace]
             evt.interface(:stacktrace) do |int|
               stacktrace_interface_from(int, evt, options[:backtrace])
@@ -131,9 +150,7 @@ module Raven
 
           while exc.respond_to?(:cause) && exc.cause
             exc = exc.cause
-            if context.include?(exc.object_id)
-              break
-            end
+            break if context.include?(exc.object_id)
             exceptions << exc
             context.add(exc.object_id)
           end
@@ -191,10 +208,10 @@ module Raven
     end
 
     def interface(name, value = nil, &block)
-      int = Raven.find_interface(name)
-      raise Error.new("Unknown interface: #{name}") unless int
-      @interfaces[int.name] = int.new(value, &block) if value || block
-      @interfaces[int.name]
+      int = Interface.registered[name]
+      raise(Error, "Unknown interface: #{name}") unless int
+      @interfaces[int.sentry_alias] = int.new(value, &block) if value || block
+      @interfaces[int.sentry_alias]
     end
 
     def [](key)
@@ -208,31 +225,39 @@ module Raven
     def to_hash
       data = {
         :event_id => @id,
-        :message => @message,
         :timestamp => @timestamp,
         :time_spent => @time_spent,
         :level => @level,
-        :project => @project,
         :platform => PLATFORM,
+        :sdk => SDK,
+        :contexts => {
+          :os => @os,
+          :runtime => @runtime
+        }
       }
+
       data[:logger] = @logger if @logger
       data[:culprit] = @culprit if @culprit
       data[:server_name] = @server_name if @server_name
       data[:release] = @release if @release
+      data[:environment] = @environment if @environment
       data[:fingerprint] = @fingerprint if @fingerprint
       data[:modules] = @modules if @modules
       data[:extra] = @extra if @extra
       data[:tags] = @tags if @tags
       data[:user] = @user if @user
+      data[:breadcrumbs] = @breadcrumbs.to_hash unless @breadcrumbs.empty?
       data[:checksum] = @checksum if @checksum
+
       @interfaces.each_pair do |name, int_data|
         data[name.to_sym] = int_data.to_hash
       end
+      data[:message] = message
       data
     end
 
     def get_file_context(filename, lineno, context)
-      return nil, nil, nil unless Raven::LineCache.is_valid_file(filename)
+      return nil, nil, nil unless Raven::LineCache.valid_file?(filename)
       lines = Array.new(2 * context + 1) do |i|
         Raven::LineCache.getline(filename, lineno - context + i)
       end
@@ -244,24 +269,29 @@ module Raven
       "#{lastframe.filename} in #{lastframe.function} at line #{lastframe.lineno}" if lastframe
     end
 
+    def to_json_compatible
+      JSON.parse(JSON.generate(to_hash))
+    end
+
     # For cross-language compat
     class << self
-      alias :captureException :from_exception
-      alias :captureMessage :from_message
-      alias :capture_exception :from_exception
-      alias :capture_message :from_message
+      alias captureException from_exception
+      alias captureMessage from_message
+      alias capture_exception from_exception
+      alias capture_message from_message
     end
 
     private
 
-    def generate_event_id
-      # generate a uuid. copy-pasted from SecureRandom, this method is not
-      # available in <1.9.
-      ary = SecureRandom.random_bytes(16).unpack("NnnnnN")
-      ary[2] = (ary[2] & 0x0fff) | 0x4000
-      ary[3] = (ary[3] & 0x3fff) | 0x8000
-      uuid = "%08x-%04x-%04x-%04x-%04x%08x" % ary
-      ::Digest::MD5.hexdigest(uuid)
+    # When behind a proxy (or if the user is using a proxy), we can't use
+    # REMOTE_ADDR to determine the Event IP, and must use other headers instead.
+    def calculate_real_ip_from_rack
+      Utils::RealIp.new(
+        :remote_addr => context.rack_env["REMOTE_ADDR"],
+        :client_ip => context.rack_env["HTTP_CLIENT_IP"],
+        :real_ip => context.rack_env["HTTP_X_REAL_IP"],
+        :forwarded_for => context.rack_env["HTTP_X_FORWARDED_FOR"]
+      ).calculate_ip
     end
   end
 end
