@@ -41,9 +41,6 @@ module Raven
     end
 
     def call(env)
-      # clear context at the beginning of the request to ensure a clean slate
-      Context.clear!
-
       # store the current environment in our local context for arbitrary
       # callers
       env['raven.requested_at'] = Time.now
@@ -54,7 +51,6 @@ module Raven
       rescue Error
         raise # Don't capture Raven errors
       rescue Exception => e
-        Raven.logger.debug "Collecting %p: %s" % [ e.class, e.message ]
         Raven::Rack.capture_exception(e, env)
         raise
       end
@@ -63,6 +59,9 @@ module Raven
       Raven::Rack.capture_exception(error, env) if error
 
       response
+    ensure
+      Context.clear!
+      BreadcrumbBuffer.clear!
     end
   end
 
@@ -84,8 +83,8 @@ module Raven
     def read_data_from(request)
       if request.form_data?
         request.POST
-      elsif request.body
-        data = request.body.read
+      elsif request.body # JSON requests, etc
+        data = request.body.read(2048) # Sentry server limit
         request.body.rewind
         data
       end
