@@ -2,7 +2,7 @@ module Raven
   class Processor::PostData < Processor
     def process(data)
       if data[:request] && data[:request][:method] == "POST"
-        data[:request][:data] = nil # Remove possibly sensitive POST data
+        data[:request][:data] = STRING_MASK # Remove possibly sensitive POST data
       end
 
       data
