@@ -8,13 +8,14 @@ describe "CLI tests" do
     end
 
     Raven.configure do |config|
-      config.server = 'http://12345:67890@sentry.localdomain/sentry/42'
       config.environments = ["test"]
       config.current_environment = "test"
       config.http_adapter = [:test, stubs]
+      config.silence_ready = true
     end
 
-    expect { Raven::CLI.test }.not_to raise_error
+    dsn = 'http://12345:67890@sentry.localdomain/sentry/42'
+    Raven::CLI.test(dsn, true)
 
     stubs.verify_stubbed_calls
   end
@@ -28,11 +29,11 @@ describe "CLI tests" do
       config.environments = ["test"]
       config.current_environment = "test"
       config.http_adapter = [:test, stubs]
+      config.silence_ready = true
     end
 
-    expect {
-      Raven::CLI.test 'http://12345:67890@sentry.localdomain/prefix/sentry/42'
-    }.not_to raise_error
+    dsn = 'http://12345:67890@sentry.localdomain/prefix/sentry/42'
+    Raven::CLI.test(dsn, true)
 
     stubs.verify_stubbed_calls
   end
