@@ -3,23 +3,23 @@ require 'spec_helper'
 describe Raven::Event do
   before do
     Raven::Context.clear!
+    Raven::BreadcrumbBuffer.clear!
   end
 
   context 'a fully implemented event' do
     let(:hash) do
-      Raven::Event.new({
-        :message => 'test',
-        :level => 'warning',
-        :logger => 'foo',
-        :tags => {
-          'foo' => 'bar'
-        },
-        :extra => {
-          'my_custom_variable' => 'value'
-        },
-        :server_name => 'foo.local',
-        :release => '721e41770371db95eee98ca2707686226b993eda',
-      }).to_hash
+      Raven::Event.new(:message => 'test',
+                       :level => 'warning',
+                       :logger => 'foo',
+                       :tags => {
+                         'foo' => 'bar'
+                       },
+                       :extra => {
+                         'my_custom_variable' => 'value'
+                       },
+                       :server_name => 'foo.local',
+                       :release => '721e41770371db95eee98ca2707686226b993eda',
+                       :environment => 'production').to_hash
     end
 
     it 'has message' do
@@ -42,100 +42,94 @@ describe Raven::Event do
       expect(hash[:release]).to eq('721e41770371db95eee98ca2707686226b993eda')
     end
 
+    it 'has environment' do
+      expect(hash[:environment]).to eq('production')
+    end
+
     it 'has tag data' do
-      expect(hash[:tags]).to eq({
-        'foo' => 'bar'
-      })
+      expect(hash[:tags]).to eq('foo' => 'bar')
     end
 
     it 'has extra data' do
-      expect(hash[:extra]).to eq({
-        'my_custom_variable' => 'value'
-      })
+      expect(hash[:extra]).to eq('my_custom_variable' => 'value')
     end
 
     it 'has platform' do
       expect(hash[:platform]).to eq('ruby')
     end
+
+    it 'has SDK' do
+      expect(hash[:sdk]).to eq("name" => "sentry-raven", "version" => Raven::VERSION)
+    end
+
+    it 'has os' do
+      expect(hash[:contexts][:os].keys).to eq(%w(name version build kernel_version))
+    end
+
+    it 'has runtime' do
+      expect(hash[:contexts][:runtime]["version"]).to match(/ruby/)
+    end
   end
 
   context 'user context specified' do
     let(:hash) do
-      Raven.user_context({
-        'id' => 'hello',
-      })
+      Raven.user_context('id' => 'hello')
 
-      Raven::Event.new({
-        :level => 'warning',
-        :logger => 'foo',
-        :tags => {
-          'foo' => 'bar'
-        },
-        :extra => {
-          'my_custom_variable' => 'value'
-        },
-        :server_name => 'foo.local',
-      }).to_hash
+      Raven::Event.new(:level => 'warning',
+                       :logger => 'foo',
+                       :tags => {
+                         'foo' => 'bar'
+                       },
+                       :extra => {
+                         'my_custom_variable' => 'value'
+                       },
+                       :server_name => 'foo.local').to_hash
     end
 
     it "adds user data" do
-      expect(hash[:user]).to eq({
-        'id' => 'hello',
-      })
+      expect(hash[:user]).to eq('id' => 'hello')
     end
   end
 
   context 'tags context specified' do
     let(:hash) do
-      Raven.tags_context({
-        'key' => 'value',
-      })
+      Raven.tags_context('key' => 'value')
 
-      Raven::Event.new({
-        :level => 'warning',
-        :logger => 'foo',
-        :tags => {
-          'foo' => 'bar'
-        },
-        :extra => {
-          'my_custom_variable' => 'value'
-        },
-        :server_name => 'foo.local',
-      }).to_hash
+      Raven::Event.new(:level => 'warning',
+                       :logger => 'foo',
+                       :tags => {
+                         'foo' => 'bar'
+                       },
+                       :extra => {
+                         'my_custom_variable' => 'value'
+                       },
+                       :server_name => 'foo.local').to_hash
     end
 
     it "merges tags data" do
-      expect(hash[:tags]).to eq({
-        'key' => 'value',
-        'foo' => 'bar',
-      })
+      expect(hash[:tags]).to eq('key' => 'value',
+                                'foo' => 'bar')
     end
   end
 
   context 'extra context specified' do
     let(:hash) do
-      Raven.extra_context({
-        'key' => 'value',
-      })
+      Raven.extra_context('key' => 'value')
 
-      Raven::Event.new({
-        :level => 'warning',
-        :logger => 'foo',
-        :tags => {
-          'foo' => 'bar'
-        },
-        :extra => {
-          'my_custom_variable' => 'value'
-        },
-        :server_name => 'foo.local',
-      }).to_hash
+      Raven::Event.new(:level => 'warning',
+                       :logger => 'foo',
+                       :tags => {
+                         'foo' => 'bar'
+                       },
+                       :extra => {
+                         'my_custom_variable' => 'value'
+                       },
+                       :server_name => 'foo.local').to_hash
     end
 
     it "merges extra data" do
-      expect(hash[:extra]).to eq({
-        'key' => 'value',
-        'my_custom_variable' => 'value',
-      })
+      expect(hash[:extra]).to eq('key' => 'value',
+                                 'my_custom_variable' => 'value')
     end
   end
 
@@ -143,40 +137,54 @@ describe Raven::Event do
     require 'stringio'
 
     let(:hash) do
-      Raven.rack_context({
-        'REQUEST_METHOD' => 'POST',
-        'QUERY_STRING' => 'biz=baz',
-        'HTTP_HOST' => 'localhost',
-        'SERVER_NAME' => 'localhost',
-        'SERVER_PORT' => '80',
-        'PATH_INFO' => '/lol',
-        'rack.url_scheme' => 'http',
-        'rack.input' => StringIO.new('foo=bar'),
-      })
+      Raven.rack_context('REQUEST_METHOD' => 'POST',
+                         'QUERY_STRING' => 'biz=baz',
+                         'HTTP_HOST' => 'localhost',
+                         'SERVER_NAME' => 'localhost',
+                         'SERVER_PORT' => '80',
+                         'HTTP_X_FORWARDED_FOR' => '1.1.1.1, 2.2.2.2',
+                         'REMOTE_ADDR' => '192.168.1.1',
+                         'PATH_INFO' => '/lol',
+                         'rack.url_scheme' => 'http',
+                         'rack.input' => StringIO.new('foo=bar'))
 
-      Raven::Event.new({
-        :level => 'warning',
-        :logger => 'foo',
-        :tags => {
-          'foo' => 'bar'
-        },
-        :extra => {
-          'my_custom_variable' => 'value'
-        },
-        :server_name => 'foo.local',
-      }).to_hash
+      Raven::Event.new(:level => 'warning',
+                       :logger => 'foo',
+                       :tags => {
+                         'foo' => 'bar'
+                       },
+                       :extra => {
+                         'my_custom_variable' => 'value'
+                       },
+                       :server_name => 'foo.local').to_hash
     end
 
     it "adds http data" do
-      expect(hash[:request]).to eq({
-        :data => { 'foo' => 'bar' },
-        :env => { 'SERVER_NAME' => 'localhost', 'SERVER_PORT' => '80' },
-        :headers => { 'Host' => 'localhost' },
-        :method => 'POST',
-        :query_string => 'biz=baz',
-        :url => 'http://localhost/lol',
-        :cookies => nil
-      })
+      expect(hash[:request]).to eq(:data => { 'foo' => 'bar' },
+                                   :env => { 'SERVER_NAME' => 'localhost', 'SERVER_PORT' => '80', "REMOTE_ADDR" => "192.168.1.1" },
+                                   :headers => { 'Host' => 'localhost', "X-Forwarded-For" => "1.1.1.1, 2.2.2.2" },
+                                   :method => 'POST',
+                                   :query_string => 'biz=baz',
+                                   :url => 'http://localhost/lol',
+                                   :cookies => nil)
+    end
+
+    it "sets user context ip address correctly" do
+      expect(hash[:user][:ip_address]).to eq("1.1.1.1")
+    end
+  end
+
+  context "rack context, long body" do
+    let(:hash) do
+      Raven.rack_context('REQUEST_METHOD' => 'GET',
+                         'rack.url_scheme' => 'http',
+                         'rack.input' => StringIO.new('a' * 16_000))
+
+      Raven::Event.new.to_hash
+    end
+
+    it "truncates http data" do
+      expect(hash[:request][:data]).to eq("a" * 2048)
     end
   end
 
@@ -197,10 +205,8 @@ describe Raven::Event do
     end
 
     it 'merges tags data' do
-      expect(hash[:tags]).to eq({
-        'key' => 'value',
-        'foo' => 'bar'
-      })
+      expect(hash[:tags]).to eq('key' => 'value',
+                                'foo' => 'bar')
     end
   end
 
@@ -233,18 +239,16 @@ describe Raven::Event do
     let(:hash) do
       config = Raven::Configuration.new
       config.tags = {
-          'configuration_context_event_key' => 'configuration_value',
-          'configuration_context_key' => 'configuration_value',
-          'configuration_event_key' => 'configuration_value',
-          'configuration_key' => 'configuration_value',
+        'configuration_context_event_key' => 'configuration_value',
+        'configuration_context_key' => 'configuration_value',
+        'configuration_event_key' => 'configuration_value',
+        'configuration_key' => 'configuration_value'
       }
 
-      Raven.tags_context({
-        'configuration_context_event_key' => 'context_value',
-        'configuration_context_key' => 'context_value',
-        'context_event_key' => 'context_value',
-        'context_key' => 'context_value',
-      })
+      Raven.tags_context('configuration_context_event_key' => 'context_value',
+                         'configuration_context_key' => 'context_value',
+                         'context_event_key' => 'context_value',
+                         'context_key' => 'context_value')
 
       Raven::Event.new(
         :level => 'warning',
@@ -253,7 +257,7 @@ describe Raven::Event do
           'configuration_context_event_key' => 'event_value',
           'configuration_event_key' => 'event_value',
           'context_event_key' => 'event_value',
-          'event_key' => 'event_value',
+          'event_key' => 'event_value'
         },
         :server_name => 'foo.local',
         :configuration => config
@@ -261,67 +265,53 @@ describe Raven::Event do
     end
 
     it 'merges tags data' do
-      expect(hash[:tags]).to eq({
-        'configuration_context_event_key' => 'event_value',
-        'configuration_context_key' => 'context_value',
-        'configuration_event_key' => 'event_value',
-        'context_event_key' => 'event_value',
-        'configuration_key' => 'configuration_value',
-        'context_key' => 'context_value',
-        'event_key' => 'event_value',
-      })
+      expect(hash[:tags]).to eq('configuration_context_event_key' => 'event_value',
+                                'configuration_context_key' => 'context_value',
+                                'configuration_event_key' => 'event_value',
+                                'context_event_key' => 'event_value',
+                                'configuration_key' => 'configuration_value',
+                                'context_key' => 'context_value',
+                                'event_key' => 'event_value')
     end
   end
 
   context 'merging user context' do
     before do
-      Raven.user_context({
-        'context_event_key' => 'context_value',
-        'context_key' => 'context_value',
-      })
+      Raven.user_context('context_event_key' => 'context_value',
+                         'context_key' => 'context_value')
     end
 
     let(:hash) do
-      Raven::Event.new({
-        :user => {
-          'context_event_key' => 'event_value',
-          'event_key' => 'event_value',
-        },
-      }).to_hash
+      Raven::Event.new(:user => {
+                         'context_event_key' => 'event_value',
+                         'event_key' => 'event_value'
+                       }).to_hash
     end
 
     it 'prioritizes event context over request context' do
-      expect(hash[:user]).to eq({
-        'context_event_key' => 'event_value',
-        'context_key' => 'context_value',
-        'event_key' => 'event_value',
-      })
+      expect(hash[:user]).to eq('context_event_key' => 'event_value',
+                                'context_key' => 'context_value',
+                                'event_key' => 'event_value')
     end
   end
 
   context 'merging extra context' do
     before do
-      Raven.extra_context({
-        'context_event_key' => 'context_value',
-        'context_key' => 'context_value',
-      })
+      Raven.extra_context('context_event_key' => 'context_value',
+                          'context_key' => 'context_value')
     end
 
     let(:hash) do
-      Raven::Event.new({
-        :extra => {
-          'context_event_key' => 'event_value',
-          'event_key' => 'event_value',
-        },
-      }).to_hash
+      Raven::Event.new(:extra => {
+                         'context_event_key' => 'event_value',
+                         'event_key' => 'event_value'
+                       }).to_hash
     end
 
     it 'prioritizes event context over request context' do
-      expect(hash[:extra]).to eq({
-        'context_event_key' => 'event_value',
-        'context_key' => 'context_value',
-        'event_key' => 'event_value',
-      })
+      expect(hash[:extra]).to eq('context_event_key' => 'event_value',
+                                 'context_key' => 'context_value',
+                                 'event_key' => 'event_value')
     end
   end
 
@@ -329,27 +319,23 @@ describe Raven::Event do
     class ExceptionWithContext < StandardError
       def raven_context
         { :extra => {
-            'context_event_key' => 'context_value',
-            'context_key' => 'context_value'
+          'context_event_key' => 'context_value',
+          'context_key' => 'context_value'
         } }
       end
     end
 
     let(:hash) do
-      Raven::Event.from_exception(ExceptionWithContext.new, {
-        :extra => {
-          'context_event_key' => 'event_value',
-          'event_key' => 'event_value',
-        },
-      }).to_hash
+      Raven::Event.from_exception(ExceptionWithContext.new, :extra => {
+                                    'context_event_key' => 'event_value',
+                                    'event_key' => 'event_value'
+                                  }).to_hash
     end
 
     it 'prioritizes event context over request context' do
-      expect(hash[:extra]).to eq({
-        'context_event_key' => 'event_value',
-        'context_key' => 'context_value',
-        'event_key' => 'event_value',
-      })
+      expect(hash[:extra]).to eq('context_event_key' => 'event_value',
+                                 'context_key' => 'context_value',
+                                 'event_key' => 'event_value')
     end
   end
 
@@ -359,7 +345,25 @@ describe Raven::Event do
         config.current_environment = 'test'
       end
       Raven.rack_context({})
-      expect { Raven::Event.new }.not_to raise_error
+      Raven::Event.new
+    end
+  end
+
+  describe '.to_json_compatible' do
+    subject do
+      Raven::Event.new(:extra => {
+                         'my_custom_variable' => 'value',
+                         'date' => Time.utc(0),
+                         'anonymous_module' => Class.new
+                       })
+    end
+
+    it "should coerce non-JSON-compatible types" do
+      json = subject.to_json_compatible
+
+      expect(json["extra"]['my_custom_variable']).to eq('value')
+      expect(json["extra"]['date']).to be_a(String)
+      expect(json["extra"]['anonymous_module']).not_to be_a(Class)
     end
   end
 
@@ -386,7 +390,7 @@ describe Raven::Event do
 
       it 'accepts a stacktrace' do
         backtrace = ["/path/to/some/file:22:in `function_name'",
-          "/some/other/path:1412:in `other_function'"]
+                     "/some/other/path:1412:in `other_function'"]
         evt = Raven::Event.capture_message(message, :backtrace => backtrace)
         expect(evt[:stacktrace]).to be_a(Raven::StacktraceInterface)
 
@@ -437,7 +441,7 @@ describe Raven::Event do
 
     context 'for a nested exception type' do
       module Raven::Test
-        class Exception < Exception; end
+        class Exception < RuntimeError; end
       end
       let(:exception) { Raven::Test::Exception.new(message) }
 
@@ -455,7 +459,7 @@ describe Raven::Event do
 
     context 'for an excluded exception type' do
       module Raven::Test
-        class BaseExc < Exception; end
+        class BaseExc < RuntimeError; end
         class SubExc < BaseExc; end
       end
 
@@ -463,7 +467,7 @@ describe Raven::Event do
         config = Raven::Configuration.new
         config.excluded_exceptions << 'Raven::Test::BaseExc'
         expect(Raven::Event.capture_exception(Raven::Test::BaseExc.new,
-                                       :configuration => config)).to be_nil
+                                              :configuration => config)).to be_nil
       end
 
       it 'returns nil for a class match' do
@@ -471,7 +475,7 @@ describe Raven::Event do
         config.excluded_exceptions << Raven::Test::BaseExc
 
         expect(Raven::Event.capture_exception(Raven::Test::SubExc.new,
-                                       :configuration => config)).to be_nil
+                                              :configuration => config)).to be_nil
       end
     end
 
@@ -506,7 +510,7 @@ describe Raven::Event do
       context 'when running under jRuby' do
         let(:exception) do
           begin
-            raise java.lang.OutOfMemoryError.new("A Java error")
+            raise java.lang.OutOfMemoryError, "A Java error"
           rescue Exception => e
             return e
           end
