@@ -45,8 +45,8 @@ describe "Integration tests" do
       config.http_adapter = [:test, stubs]
     end
 
-    expect(Raven.logger).to receive(:warn).once
-    expect { Raven.capture_exception(build_exception) }.not_to raise_error
+    expect(Raven.logger).to receive(:error).at_least(10).times
+    Raven.capture_exception(build_exception)
 
     stubs.verify_stubbed_calls
   end
