@@ -1,14 +1,17 @@
 require "spec_helper"
 require "rspec/rails"
 require "raven/transports/dummy"
+require "raven/integrations/rack"
+require "raven/integrations/rails"
 
 describe TestApp, :type => :request do
   before(:all) do
     Raven.configure do |config|
       config.dsn = 'dummy://notaserver'
       config.encoding = 'json'
-      config.logger = nil
+      config.logger = false
     end
+    Rails.logger = Logger.new(nil)
     Rails.env = "production"
     TestApp.initialize!
   end
@@ -30,7 +33,6 @@ describe TestApp, :type => :request do
   it "should properly set the exception's URL" do
     get "/exception"
 
-    # TODO: dummy transport shouldn't even encode the event
     event = Raven.client.transport.events.first
     event = JSON.parse!(event[1])
 
