@@ -1,11 +1,11 @@
 require 'spec_helper'
 
 describe Raven do
-  let(:event) { double("event", :id => "event_id") }
+  let(:event) { Raven::Event.new(:id => "event_id") }
   let(:options) { double("options") }
 
   before do
-    allow(Raven).to receive(:send_event)
+    allow(Raven.instance).to receive(:send_event)
     allow(Raven::Event).to receive(:from_message) { event }
     allow(Raven::Event).to receive(:from_exception) { event }
   end
@@ -15,7 +15,7 @@ describe Raven do
 
     it 'sends the result of Event.capture_message' do
       expect(Raven::Event).to receive(:from_message).with(message, options)
-      expect(Raven).to receive(:send_event).with(event)
+      expect(Raven.instance).to receive(:send_event).with(event)
 
       Raven.capture_message(message, options)
     end
@@ -30,7 +30,7 @@ describe Raven do
 
     around do |example|
       prior_async = Raven.configuration.async
-      Raven.configuration.async = Proc.new { :ok }
+      Raven.configuration.async = proc { :ok }
       example.run
       Raven.configuration.async = prior_async
     end
@@ -39,7 +39,7 @@ describe Raven do
       expect(Raven::Event).to receive(:from_message).with(message, options)
       expect(Raven).not_to receive(:send_event).with(event)
 
-      expect(Raven.configuration.async).to receive(:call).with(event)
+      expect(Raven.configuration.async).to receive(:call).with(event.to_json_compatible)
       Raven.capture_message(message, options)
     end
 
@@ -54,7 +54,7 @@ describe Raven do
 
     it 'sends the result of Event.capture_exception' do
       expect(Raven::Event).to receive(:from_exception).with(exception, options)
-      expect(Raven).to receive(:send_event).with(event)
+      expect(Raven.instance).to receive(:send_event).with(event)
 
       Raven.capture_exception(exception, options)
     end
@@ -69,7 +69,7 @@ describe Raven do
 
     around do |example|
       prior_async = Raven.configuration.async
-      Raven.configuration.async = Proc.new { :ok }
+      Raven.configuration.async = proc { :ok }
       example.run
       Raven.configuration.async = prior_async
     end
@@ -78,7 +78,7 @@ describe Raven do
       expect(Raven::Event).to receive(:from_exception).with(exception, options)
       expect(Raven).not_to receive(:send_event).with(event)
 
-      expect(Raven.configuration.async).to receive(:call).with(event)
+      expect(Raven.configuration.async).to receive(:call).with(event.to_json_compatible)
       Raven.capture_exception(exception, options)
     end
 
@@ -95,7 +95,7 @@ describe Raven do
       expect(Raven).not_to receive(:send_event).with(event)
 
       prior_should_capture = Raven.configuration.should_capture
-      Raven.configuration.should_capture = Proc.new { false }
+      Raven.configuration.should_capture = proc { false }
       expect(Raven.configuration.should_capture).to receive(:call).with(exception)
       expect(Raven.capture_exception(exception, options)).to be false
       Raven.configuration.should_capture = prior_should_capture
@@ -107,11 +107,6 @@ describe Raven do
       it 'yields to the given block' do
         expect { |b| described_class.capture(&b) }.to yield_with_no_args
       end
-
-      it 'does not install an exit_hook' do
-        expect(described_class).not_to receive(:install_at_exit_hook)
-        described_class.capture {}
-      end
     end
 
     context 'not given a block' do
@@ -124,7 +119,7 @@ describe Raven do
           pipe_in.close
           described_class.capture(options)
 
-          allow(Raven).to receive(:capture_exception) do |exception, _options|
+          allow(Raven.instance).to receive(:capture_type) do |exception, _options|
             pipe_out.puts exception.message
           end
 
@@ -132,14 +127,13 @@ describe Raven do
           $stderr.reopen('/dev/null', 'w')
           $stdout.reopen('/dev/null', 'w')
 
-          raise 'test error'
+          yield
           exit
         end
 
         pipe_out.close
         captured_messages = pipe_in.read
         pipe_in.close
-
         # sometimes the at_exit hook was registered multiple times
         captured_messages.split("\n").last
       end
@@ -149,7 +143,7 @@ describe Raven do
         # is not valid: expect { |b| described_class.capture }.to_not yield_control),
         # expect that a LocalJumpError, which is raised when yielding when no
         # block is defined, is not raised.
-        expect { described_class.capture }.not_to raise_error
+        described_class.capture
       end
 
       it 'installs an at exit hook that will capture exceptions' do
@@ -182,13 +176,13 @@ describe Raven do
     end
 
     let(:not_ready_message) do
-      "Raven #{Raven::VERSION} configured not to send errors."
+      "Raven #{Raven::VERSION} configured not to capture errors."
     end
 
     it 'logs a ready message when configured' do
       Raven.configuration.silence_ready = false
       expect(Raven.configuration).to(
-        receive(:send_in_current_environment?).and_return(true)
+        receive(:capture_allowed?).and_return(true)
       )
       expect(Raven.logger).to receive(:info).with(ready_message)
       Raven.report_status
@@ -197,7 +191,7 @@ describe Raven do
     it 'logs not ready message if the config does not send in current environment' do
       Raven.configuration.silence_ready = false
       expect(Raven.configuration).to(
-        receive(:send_in_current_environment?).and_return(false)
+        receive(:capture_allowed?).and_return(false)
       )
       expect(Raven.logger).to receive(:info).with(not_ready_message)
       Raven.report_status
@@ -212,7 +206,7 @@ describe Raven do
 
   describe '.inject_only' do
     before do
-      allow(Gem.loaded_specs).to receive(:keys).and_return(%w[railties rack sidekiq])
+      allow(Gem.loaded_specs).to receive(:keys).and_return(%w(railties rack sidekiq))
     end
 
     it 'loads integrations when they are valid configurations' do
@@ -244,7 +238,7 @@ describe Raven do
     it 'injects all integrations except those passed as an argument' do
       expect(Raven).to receive(:load_integration).once.with('rake')
 
-      Raven.inject_without(:delayed_job, :railties, :sidekiq, :rack)
+      Raven.inject_without(:delayed_job, :logger, :railties, :sidekiq, :rack, :"rack-timeout")
     end
   end
 
@@ -252,7 +246,7 @@ describe Raven do
     let(:message) { "Test message" }
 
     it 'sends the result of Event.capture_message' do
-      expect(Raven).to receive(:send_event).with(event)
+      expect(Raven.instance).to receive(:send_event).with(event)
 
       Raven.capture_message("Test message", options)
 
@@ -263,4 +257,14 @@ describe Raven do
       expect { |b| Raven.capture_message(message, options, &b) }.to yield_with_args(event)
     end
   end
+
+  describe "#sys_command" do
+    it "should execute system commands" do
+      expect(Raven.sys_command("echo 'Sentry'")).to eq("Sentry")
+    end
+
+    it "should return nil if a system command doesn't exist" do
+      expect(Raven.sys_command("asdasdasdsa")).to eq(nil)
+    end
+  end
 end
