@@ -16,25 +16,25 @@ end
 
 def build_exception_with_cause
   begin
-    1 / 0
-  rescue ZeroDivisionError
-    1 / 0
+    raise "exception a"
+  rescue
+    raise "exception b"
   end
-rescue ZeroDivisionError => exception
+rescue RuntimeError => exception
   return exception
 end
 
 def build_exception_with_two_causes
   begin
     begin
-      1 / 0
-    rescue ZeroDivisionError
-      1 / 0
+      raise "exception a"
+    rescue
+      raise "exception b"
     end
-  rescue ZeroDivisionError
-    1 / 0
+  rescue
+    raise "exception c"
   end
-rescue ZeroDivisionError => exception
+rescue RuntimeError => exception
   return exception
 end
 
@@ -45,5 +45,5 @@ def build_exception_with_recursive_cause
   allow(exception).to receive(:cause).and_return(exception)
   allow(exception).to receive(:message).and_return("example")
   allow(exception).to receive(:backtrace).and_return(backtrace)
-  return exception
+  exception
 end
